.. poismf documentation master file, created by
   sphinx-quickstart on Wed Jul 31 23:11:33 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Poisson factorization for sparse count matrices
===============================================
For more information, visit the project's homepage
`<https://www.github.com/david-cortes/poismf>`_


.. toctree::
   :maxdepth: 2
   :caption: Contents:


.. automodule:: poismf
    :members:
    :undoc-members:
    :show-inheritance:
    :inherited-members:



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
